@@ -2,8 +2,8 @@
 
 createdb conntest
 
-./pgbouncer -d ctest6000.ini
-./pgbouncer -d ctest7000.ini
+../pgbouncer -d ctest6000.ini
+../pgbouncer -d ctest7000.ini
 
 ./asynctest
 
